#
# spec file for package python-influxdb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Legacy package not compatible with Python 3.12 and newer. Move your consuming library to a more modern version!
%define skip_python312 1
%define skip_python313 1
Name:           python-influxdb
Version:        5.3.2
Release:        2.2
Summary:        InfluxDB client
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/influxdb/influxdb-python
Source:         https://files.pythonhosted.org/packages/source/i/influxdb/influxdb-%{version}.tar.gz
# https://github.com/influxdata/influxdb-python/pull/835
Patch0:         python-influxdb-remove-nose.patch
# PATCH-FIX-UPSTREAM influxdb-pr845-pandas-future.patch -- gh#influxdb/influxdb-python#845
Patch1:         influxdb-pr845-pandas-future.patch
# do not require six (repo archived in favour of influxdb2, not reporting)
Patch2:         python-influxdb-no-six.patch
# fix tests with newer pandas
Patch3:         python-influxdb-new-pandas.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-dateutil >= 2.6.0}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests >= 2.17.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-msgpack
Requires:       python-python-dateutil >= 2.6.0
Requires:       python-pytz
Requires:       python-requests >= 2.17.0
# Pandas is optional but only works with pandas >= 2.1. If pandas < 2.1 is installed, the module throws an ImportError
Conflicts:      python-pandas < 2.1
ExcludeArch:    %ix86 %arm ppc
# SECTION test requirements
BuildRequires:  %{python_module msgpack}
BuildRequires:  %{python_module pandas >= 2.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  influxdb
%if 0%{?suse_version} >= 1500
BuildRequires:  hostname
%endif
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
InfluxDB-Python is a client for interacting with InfluxDB 1.x

%prep
%autosetup -p1 -n influxdb-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# remove extra mock
sed -e 's/^import mock/from unittest import mock/' \
    -e 's/^from mock import/from unittest.mock import/' \
    -i influxdb/tests/*.py influxdb/tests/*/*.py
# https://github.com/influxdata/influxdb-python/issues/884
donttest="test_write_points_from_dataframe_with_nan_json or test_write_points_from_dataframe_with_tags_and_nan_json"
# don't work with numpy 2
donttest+=" or test_multiquery_into_dataframe_dropna"
%pytest influxdb -k "not ($donttest)"

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/influxdb
%{python_sitelib}/influxdb-%{version}.dist-info

%changelog
* Tue Nov 26 2024 Nico Krapp <nico.krapp@suse.com>
- Skip python313 flavor as this package only supports up to python311
* Wed Sep 11 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to 5.3.2:
  * Correctly serialize nanosecond dataframe timestamps (#926)
- Refresh all patches and skip broken test with numpy >= 2
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Update python-influxdb-new-pandas.patch once more
* Sun Feb 18 2024 Ben Greiner <code@bnavigator.de>
- Skip python312 flavor. This legacy package is not compatible with
  Python 3.12. Makes gh#openSUSE/openSUSE-release-tools#3034 more
  pressing.
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update python-influxdb-new-pandas.patch in order to avoid
  FutureWarning: does not work with pandas < 2.1
- Make pure python a noarch package
- PEP 517
- Upstream is archived, but still required by
  openSUSE-release-tools gh#openSUSE/openSUSE-release-tools#3034
* Mon Jun 19 2023 Fabian Vogt <fvogt@suse.com>
- Add patch to fix tests with newer pandas:
  * python-influxdb-new-pandas.patch
* Fri Jun  2 2023 pgajdos@suse.com
- do not require six
- modified patches
  %% python-influxdb-remove-nose.patch (refreshed)
- added patches
  do not require six (repo archived in favour of influxdb2, not reporting)
  + python-influxdb-no-six.patch
* Fri Dec  9 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Sync ExcludeArch with influxdb. By definition, this package is no
  longer noarch, as it's not usable/installable on all
  architectures (missing deps).
* Thu Apr 15 2021 Ben Greiner <code@bnavigator.de>
- Skip python36: Extensive use of pandas in the test suite
- Add influxdb-pr845-pandas-future.patch
  gh#influxdb/influxdb-python#845
- Skip tests failing with pandas -- #influxdb/influxdb-python#884
- Don't use extra mock
* Tue Feb  2 2021 Dirk Müller <dmueller@suse.com>
- update to 5.3.1:
  * Add support for custom headers in the InfluxDBClient
  * Add support for custom indexes for query in the DataFrameClient
  * Amend retry to avoid sleep after last retry before raising exception
  * Remove msgpack pinning for requirements
  * Update support for HTTP headers in the InfluxDBClient
* Wed Jul  8 2020 pgajdos@suse.com
- do not depend on deprecated nose
- added patches
  https://github.com/influxdata/influxdb-python/pull/835
  + python-influxdb-remove-nose.patch
* Tue Apr 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 5.3.0
  * Add mypy testing framework (#756)
  * Add support for messagepack (#734 thx @lovasoa)
  * Add support for 'show series' (#357 thx @gaker)
  * Add support for custom request session in InfluxDBClient (#360 thx @dschien)
  * Add support for handling np.nan and np.inf values in DataFrameClient (#436 thx @nmerket)
  * Add support for optional `time_precision` in the SeriesHelper (#502 && #719 thx @appunni-dishq && @klDen)
  * Add ability to specify retention policy in SeriesHelper (#723 thx @csanz91)
  * Add gzip compression for post and response data (#732 thx @KEClaytor)
  * Add support for chunked responses in ResultSet (#753 and #538 thx @hrbonz && @psy0rz)
  * Add support for empty string fields (#766 thx @gregschrock)
  * Add support for context managers to InfluxDBClient (#721 thx @JustusAdam)
  * Clean up stale CI config (#755)
  * Add legacy client test (#752 & #318 thx @oldmantaiter & @sebito91)
  * Update make_lines section in line_protocol.py to split out core function (#375 thx @aisbaa)
  * Fix nanosecond time resolution for points (#407 thx @AndreCAndersen && @clslgrnc)
  * Fix import of distutils.spawn (#805 thx @Hawk777)
  * Update repr of float values including properly handling of boolean (#488 thx @ghost)
  * Update DataFrameClient to fix faulty empty tags (#770 thx @michelfripiat)
  * Update DataFrameClient to properly return `dropna` values (#778 thx @jgspiro)
  * Update DataFrameClient to test for pd.DataTimeIndex before blind conversion (#623 thx @testforvin)
  * Update client to type-set UDP port to int (#651 thx @yifeikong)
  * Update batched writing support for all iterables (#746 thx @JayH5)
  * Update SeriesHelper to enable class instantiation when not initialized (#772 thx @ocworld)
  * Update UDP test case to add proper timestamp to datapoints (#808 thx @shantanoo-desai)
- Drop upstreamed patch python-influxdb-fix-testsuite.patch
* Tue Mar 10 2020 Dirk Mueller <dmueller@suse.com>
- skip python 2.x build (pandas went py3 only)
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.2.3:
  * Add consistency param to InfluxDBClient.write_points (#643 thx @RonRothman)
  * Add UDP example (#648 thx @shantanoo-desai)
  * Add consistency paramter to write_points (#664 tx @RonRothman)
  * The query() function now accepts a bind_params argument for parameter binding (#678 thx @clslgrnc)
  * Add get_list_continuous_queries, drop_continuous_query, and create_continuous_query management methods for continuous queries (#681 thx @lukaszdudek-silvair)
  * Mutual TLS authentication (#702 thx @LloydW93)
- Drop merged patches:
  * python-influxdb-d5d1249.patch
* Fri May 10 2019 pgajdos@suse.com
- version update to 5.2.2
  - Fix 'TypeError: Already tz-aware' introduced with recent versions of Panda
    (#671, #676, thx @f4bsch @clslgrnc)
  - Pass through the "method" kwarg to DataFrameClient queries
  - Finally add a CHANGELOG.md to communicate breaking changes (#598)
  - Test multiple versions of InfluxDB in travis
  - Add SHARD DURATION parameter to retention policy create/alter
  - Update POST/GET requests to follow verb guidelines from InfluxDB documentation
  - Update test suite to support InfluxDB v1.3.9, v1.4.2, and v1.5.4
  - Fix performance degradation when removing NaN values via line protocol (#592)
  - Dropped support for Python3.4
- added patches
  recent changes in master to fix tests
  + python-influxdb-d5d1249.patch
  fix module 'distutils' has no attribute 'spawn'
  + python-influxdb-fix-testsuite.patch
* Sun Jan 27 2019 Thomas Bechtold <tbechtold@suse.com>
- update to version v5.1.0
  * README: add PyPI status
  * Escape tag values that ends with backslash (#537)
  * Fix for  DataFrameClient issue - seems does not process correctly DateTimeIndex dates (issue #479) (#495)
  * Fix pandas example (#547)
  * Fix wrong session mount (#571)
  * set version to 5.1.0
  * DataFrameClient should escape measurement names (#542)
  * doc: clarify that send_packet takes a list (#545)
  * specify the numpy dependency explicitly to prevent regression in test (#563)
  * Parse column names in a dataframe to avoid breaking the line protocol (#584)
  * adding back dropped database param
  * Allow connecting to influxdb running on a path on the server (#556)
  * Remove comment as issues have been resolved (#581)
  * Remove UDP Precision Restrictions (#557)
  * Update _dataframe_client.py (#593)
  * README: styling
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Nov 22 2017 mimi.vx@gmail.com
- convert to singlespec
* Tue Nov 21 2017 ncutler@suse.com
- spec file
  + "hostname" build dependency only for Leap 15 and above
* Tue Nov 21 2017 ncutler@suse.com
- update to 5.0.0
  for detailed change log, see https://github.com/influxdata/influxdb-python/commits/b59fe97
- add "hostname" build dependency
* Mon Apr 10 2017 dmueller@suse.com
- remove unnecessary build requires
* Mon Jan 16 2017 dmueller@suse.com
- Initial packaging (4.0.0)
